#!/bin/bash
###############################################################
#
#        Format: s1-convertwithtags.sh module_name
#             
# convert from CVS to BZR including tags not starting with 'H'
#
# Prerequisites:
# 1. Conversion options file have the correct references to 
# - cvs2bzr-module_name-tmp.options
# 2. There are no bzr repositories in the ./bzrrepo with name:
#  - module_name-tmp
###############################################################

moduletmp=""
pwd=$PWD

export CVSROOT=$PWD/cvsrepo
bzrroot=$PWD/bzrrepo
cvsroot=$CVSROOT
echo "CVSROOT = $CVSROOT"
echo "BZRROOT = $bzrroot"


# Set the timezone to GMT
tz=$TZ
export TZ=GMT

# Test if the module name is passed as a parameter
if [ $# != 1 ] ; then
   echo "Usage: s1-convertwithtags.sh module_name"
   exit 1
else   
   moduletmp=$1-tmp
fi

###############################################################
#                      STAGE 1                                #
#                                                             #
# verify parameters                                           #
#                                                             #
###############################################################

# Test if the module exists in the repository
if [ ! -d $cvsroot/$module ]
then
   echo "$cvsroot/$module does not exist.";
   exit 1
fi

# Test if the cvs2bzr option file is in place
if [ ! -f cvs2bzr-$moduletmp.options ] ;then
   echo "The ./cvs2bzr-$moduletmp.options file does not exist"
   exit 1
fi

# If there is a bazaar repo then stop
if [ -d $bzrroot/$moduletmp ] ;then
   echo "The $bzrroot/$moduletmp directory already exists"
   exit 1
fi

# Create the bazaar repository
#rm -rf $bzrroot/$moduletmp
mkdir $bzrroot/$moduletmp
cd $bzrroot
bzr init-repo $moduletmp
bzr init $moduletmp/trunk
cd $pwd

# Starting conversion
echo "Starting conversion ..."
mkdir -p cvs2svn-2.4.0 

# Export from CVS in fi
cd $pwd/cvs2svn-2.4.0
./cvs2bzr --options=../cvs2bzr-$moduletmp.options

# make a backup
cp -f ./cvs2svn-tmp/dumpfile.fi ./cvs2svn-tmp/$moduletmp.fi

# Import from fi in BZR
bzr fast-import ./cvs2svn-tmp/dumpfile.fi $bzrroot/$moduletmp










