#!/bin/bash
###############################################################
#
#     Format:   s3-detecttime-alt.sh module_name file_name
# 
#  - this script detects timestamps for tags from a bazaar repository
#    and write this list to file_name  
#
# Prerequisites:
# - a bazaar repository converted with tags(using convertwithtags.sh)
#   located in ./bzrrepo/module_name-tmp
#
###############################################################

moduletmp=""
filename=""
pwd=$PWD

bzrroot=$PWD/bzrrepo

# Set the timezone to GMT
export TZ=GMT

# Test if the module name is passed as a parameter
if [ $# != 2 ] ; then
   echo "Usage: s3-detecttime-alt.sh module_name file_name"
   exit 1
else
   moduletmp=$1
   filename=$2
fi

# Detect timestamps for tags
workdir=$pwd/tmp-detecttime-alt

# Checkout from BZR
rm -fr $workdir
mkdir $workdir
cd $workdir

bzr checkout $bzrroot/$moduletmp/trunk .

# Extract timestamps
echo  "Wait 3-4 minutes ..."
bzr tags | awk '{printf "%s%s", $1," "} {system( "bzr log -r"  $1 " | grep timestamp")}' > ts.txt

# Copy file to destination
cd $pwd
sort $workdir/ts.txt > $filename





